Change Log — OppiaMobile 0.1.12 documentation

### Navigation

- index
- previous |
- OppiaMobile 0.1.12 documentation »

# Change Log

## v0.1.13

- Add a max upload file size (https://github.com/DigitalCampus/django-oppia/issues/8) - this prevent users uploading large course files which may make it difficult for end users to download on slow connections

## v0.1.12

- Initial release (all previous versions were for alpha testing)

### Navigation

- index
- previous |
- OppiaMobile 0.1.12 documentation »